==> brkout-0.1.tar.gz: brkout-0.1/brkout.h <==
#ifndef _BRKOUT_H
#define _BRKOUT_H

#define REPEAT_TIME 4
#define DELAY_TIME  18
#define BTN_PRESS(x) (!(cond.buttons & x) && (last_cond.buttons & x))
#define BTN_PRESS_REPEAT(x) (!(cond.buttons & x) && ((last_cond.buttons & x) || rpt_timer <= 0))
#define REPEAT_UPDATE(x) do { if (last_cond.buttons & x) rpt_timer = DELAY_TIME; else rpt_timer = REPEAT_TIME; } while (0)

#define BRICKS_X 20
#define BRICKS_Y 30
#define BRICK_W 20
#define BRICK_H 8
#define NUM_BRICKTYPES 10

/* These are here for the edit selector... hopefully they can be returned to brkout.c */
#define FIELD_X 50
#define FIELD_Y 50
#define FIELD_W (BRICK_W * BRICKS_X)
#define FIELD_H 420

#define NUM_LEVELS 256

#define LEVEL_SIZE (sizeof(brick_t) * BRICKS_X * BRICKS_Y)
#define copy_level(dest, src) do { memcpy(dest.bricks, src.bricks, sizeof(brick_t) * BRICKS_X * BRICKS_Y); dest.left = src.left; } while (0)
#define clear_level(lvl) do { memset(lvl.bricks, 0, sizeof(brick_t) * BRICKS_X * BRICKS_Y); lvl.left = 0; } while(0)
#define alloc_level(lvl) (lvl.bricks = malloc(sizeof(brick_t) * BRICKS_X * BRICKS_Y))
#define free_level(lvl) do { free(lvl.bricks); lvl.bricks = NULL; } while (0)

typedef int brick_t;
typedef struct {
	int r;
	int g;
	int b;
} color_t;

typedef struct {
	int left;
	brick_t *bricks;
} level_t;

/* Samples loaded in order */
enum { SAMPLE_SELECT, SAMPLE_ACTIVATE, SAMPLE_EDITSEL_SELECT, SAMPLE_SUCCESS, SAMPLE_BOUNCE, SAMPLE_FAILURE, SAMPLE_DISABLED, SAMPLE_CANCEL, SAMPLE_SAVORY };

extern float paddle_x, paddle_y;
extern float ball_x, ball_y;
extern float ball_dx, ball_dy;
extern uint8 maple_controller[4];
extern int bricks_left;
extern brick_t bricks[BRICKS_X * BRICKS_Y];
extern color_t brick_colors[NUM_BRICKTYPES];
extern int level;
extern int last_level;
extern pvr_poly_hdr_t op_poly_header;
extern level_t levels[NUM_LEVELS];

void draw_bricks(int lvl);
void draw_brick(int x, int y, float a, int r, int g, int b);
void draw_ball(float x, float y);
void draw_paddle(float x, float y);
void draw_walls(void);
void field_to_screen(float *x, float *y);
int screen_to_field(float *x, float *y);
void draw_poly_box(float x, float y, float dx, float dy, float z, float a, float r, float g, float b);
void draw_cross(float x, float y, float dx, float dy);
void draw_playfield_bg(void);

#endif

==> brkout-0.1.1.tar.gz: brkout-0.1.1/brkout.h <==
#ifndef _BRKOUT_H
#define _BRKOUT_H

#define REPEAT_TIME 4
#define DELAY_TIME  18
#define BTN_PRESS(x) (!(cond.buttons & (x)) && (last_cond.buttons & (x)))
#define BTN_PRESS_REPEAT(x) (!(cond.buttons & (x)) && ((last_cond.buttons & (x)) || rpt_timer <= 0))
#define REPEAT_UPDATE(x) do { if (last_cond.buttons & x) rpt_timer = DELAY_TIME; else rpt_timer = REPEAT_TIME; } while (0)

#define BRICKS_X 20
#define BRICKS_Y 30
#define BRICK_W 25
#define BRICK_H 10
#define NUM_BRICKTYPES 10

/* These are here for the edit selector... hopefully they can be returned to brkout.c */
#define FIELD_X 10
#define FIELD_Y 36
#define FIELD_W (BRICK_W * BRICKS_X)
#define FIELD_H 435

#define NUM_LEVELS 256

#define LEVEL_SIZE (sizeof(brick_t) * BRICKS_X * BRICKS_Y)
#define copy_level(dest, src) do { memcpy(dest.bricks, src.bricks, sizeof(brick_t) * BRICKS_X * BRICKS_Y); dest.left = src.left; } while (0)
#define clear_level(lvl) do { memset(lvl.bricks, 0, sizeof(brick_t) * BRICKS_X * BRICKS_Y); lvl.left = 0; } while(0)
#define alloc_level(lvl) (lvl.bricks = malloc(sizeof(brick_t) * BRICKS_X * BRICKS_Y))
#define free_level(lvl) do { free(lvl.bricks); lvl.bricks = NULL; } while (0)

typedef int brick_t;
typedef struct {
	int r;
	int g;
	int b;
} color_t;

typedef struct {
	int left;
	brick_t *bricks;
} level_t;

/* Samples loaded in order */
enum { SAMPLE_SELECT, SAMPLE_ACTIVATE, SAMPLE_EDITSEL_SELECT, SAMPLE_SUCCESS, SAMPLE_BOUNCE, SAMPLE_FAILURE, SAMPLE_DISABLED, SAMPLE_CANCEL, SAMPLE_SAVORY };

extern float paddle_x, paddle_y;
extern float ball_x, ball_y;
extern float ball_dx, ball_dy;
extern uint8 maple_controller[4];
extern int bricks_left;
extern color_t brick_colors[NUM_BRICKTYPES];
extern int level;
extern int last_level;
extern pvr_poly_hdr_t op_poly_header;
extern level_t levels[NUM_LEVELS];

void draw_bricks(int lvl);
void draw_brick(int x, int y, float a, int r, int g, int b);
void draw_ball(float x, float y);
void draw_paddle(float x, float y);
void draw_walls(void);
void field_to_screen(float *x, float *y);
int screen_to_field(float *x, float *y);
void draw_poly_box(float x, float y, float dx, float dy, float z, float a, float r, float g, float b);
void draw_cross(float x, float y, float dx, float dy);
void draw_playfield_bg(void);

#endif
